@@ -6,5 +6,6 @@ from erdpy_wallet.user_verifer import UserVerifier
 from erdpy_wallet.user_wallet import UserWallet
 from erdpy_wallet.validator_keys import ValidatorPublicKey, ValidatorSecretKey
 from erdpy_wallet.validator_signer import ValidatorSigner
+from erdpy_wallet.validator_verifier import ValidatorVerifier
 
-__all__ = ["UserSigner", "Mnemonic", "UserSecretKey", "UserPublicKey", "ValidatorSecretKey", "ValidatorPublicKey", "UserVerifier", "ValidatorSigner", "UserWallet", "UserPEM"]
+__all__ = ["UserSigner", "Mnemonic", "UserSecretKey", "UserPublicKey", "ValidatorSecretKey", "ValidatorPublicKey", "UserVerifier", "ValidatorSigner", "ValidatorVerifier", "UserWallet", "UserPEM"]
